// Copyright (c) 2002 David Muse
// See the COPYING file for more information.

	friend class logger;
	private:
		void	write(const char *string);
		filedestinationprivate	*pvt;
